@@ -1,9 +1,9 @@
 /*
- Copyright (c) 2008-2009 TrueCrypt Foundation. All rights reserved.
+ Copyright (c) 2008-2011 TrueCrypt Developers Association. All rights reserved.
 
- Governed by the TrueCrypt License 2.8 the full text of which is contained
- in the file License.txt included in TrueCrypt binary and source code
- distribution packages.
+ Governed by the TrueCrypt License 3.0 the full text of which is contained in
+ the file License.txt included in TrueCrypt binary and source code distribution
+ packages.
 */
 
 #include "Crc.h"
@@ -435,6 +435,11 @@ static byte BootEncryptedDrive ()
 	if (ExtraBootPartitionPresent && !GetActivePartition (BootDrive))
 		goto err;
 
+	if (ReadWriteMBR (false, ActivePartition.Drive) != BiosResultSuccess)
+		goto err;
+
+	bootArguments->BootDriveSignature = *(uint32 *) (SectorBuffer + 0x1b8);
+
 	if (!InstallInterruptFilters())
 		goto err;
 
@@ -1042,6 +1047,8 @@ void main ()
 
 #ifndef TC_WINDOWS_BOOT_RESCUE_DISK_MODE
 	ReadBootSectorUserConfiguration();
+#elif defined (TC_WINDOWS_BOOT_AES)
+	EnableHwEncryption (!(BootSectorFlags & TC_BOOT_CFG_FLAG_RESCUE_DISABLE_HW_ENCRYPTION));
 #endif
 
 	InitVideoMode();
