@@ -1,9 +1,9 @@
 /*
- Copyright (c) 2005 TrueCrypt Foundation. All rights reserved.
+ Copyright (c) 2005-2010 TrueCrypt Developers Association. All rights reserved.
 
- Governed by the TrueCrypt License 2.8 the full text of which is contained
- in the file License.txt included in TrueCrypt binary and source code
- distribution packages.
+ Governed by the TrueCrypt License 3.0 the full text of which is contained in
+ the file License.txt included in TrueCrypt binary and source code distribution
+ packages.
 */
 
 #ifdef __cplusplus
@@ -15,9 +15,11 @@ char *XmlFindElement (char *xmlNode, char *nodeName);
 char *XmlGetAttributeText (char *xmlNode, char *xmlAttrName, char *xmlAttrValue, int xmlAttrValueSize);
 char *XmlGetNodeText (char *xmlNode, char *xmlText, int xmlTextSize);
 int XmlWriteHeader (FILE *file);
+int XmlWriteHeaderW (FILE *file);
 int XmlWriteFooter (FILE *file);
+int XmlWriteFooterW (FILE *file);
 char *XmlFindElementByAttributeValue (char *xml, char *nodeName, char *attrName, char *attrValue);
-char *XmlQuoteText (char *textSrc, char *textDst, int textDstMaxSize);
+char *XmlQuoteText (const char *textSrc, char *textDst, int textDstMaxSize);
 
 #ifdef __cplusplus
 }
