@@ -1,12 +1,20 @@
 /*
- Copyright (c) 2008-2009 TrueCrypt Foundation. All rights reserved.
+ Copyright (c) 2008-2010 TrueCrypt Developers Association. All rights reserved.
 
- Governed by the TrueCrypt License 2.8 the full text of which is contained
- in the file License.txt included in TrueCrypt binary and source code
- distribution packages.
+ Governed by the TrueCrypt License 3.0 the full text of which is contained in
+ the file License.txt included in TrueCrypt binary and source code distribution
+ packages.
 */
 
 #include "System.h"
+
+#ifdef TC_UNIX
+#include <fcntl.h>
+#include <unistd.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+#endif
+
 #include "Common/SecurityToken.h"
 #include "Main/Main.h"
 #include "Main/Resources.h"
@@ -16,6 +24,7 @@
 #include "Main/Xml.h"
 #include "MainFrame.h"
 #include "AboutDialog.h"
+#include "BenchmarkDialog.h"
 #include "ChangePasswordDialog.h"
 #include "EncryptionTestDialog.h"
 #include "FavoriteVolumesDialog.h"
@@ -28,8 +37,10 @@
 namespace TrueCrypt
 {
 	MainFrame::MainFrame (wxWindow* parent) : MainFrameBase (parent),
+		ListItemRightClickEventPending (false),
 		SelectedItemIndex (-1),
-		SelectedSlotNumber (0)
+		SelectedSlotNumber (0),
+		ShowRequestFifo (-1)
 	{
 		wxBusyCursor busy;
 
@@ -37,6 +48,25 @@ namespace TrueCrypt
 		SetTitle (Application::GetName());
 		SetIcon (Resources::GetTrueCryptIcon());
 
+#if defined(TC_UNIX) && !defined(TC_MACOSX)
+		try
+		{
+			string fifoPath = GetShowRequestFifoPath();
+
+			remove (fifoPath.c_str());
+			throw_sys_if (mkfifo (fifoPath.c_str(), S_IRUSR | S_IWUSR) == -1);
+
+			ShowRequestFifo = open (fifoPath.c_str(), O_RDONLY | O_NONBLOCK);
+			throw_sys_if (ShowRequestFifo == -1);
+		}
+		catch (...)
+		{
+#ifdef DEBUG
+			throw;
+#endif
+		}
+#endif
+
 		InitControls();
 		InitPreferences();
 		InitTaskBarIcon();
@@ -58,6 +88,18 @@ namespace TrueCrypt
 
 	MainFrame::~MainFrame ()
 	{
+#if defined(TC_UNIX) && !defined(TC_MACOSX)
+		if (ShowRequestFifo != -1)
+		{
+			try
+			{
+				close (ShowRequestFifo);
+				remove (string (GetShowRequestFifoPath()).c_str());
+			}
+			catch (...) { }
+		}
+#endif
+
 		Core->VolumeMountedEvent.Disconnect (this);
 		Core->VolumeDismountedEvent.Disconnect (this);
 		Gui->OpenVolumeSystemRequestEvent.Disconnect (this);
@@ -418,6 +460,9 @@ namespace TrueCrypt
 
 			LoadFavoriteVolumes();
 			VolumeHistory::Load();
+
+			if (VolumePathComboBox->GetValue().empty() && !VolumeHistory::Get().empty())
+				SetVolumePath (VolumeHistory::Get().front());
 		}
 		catch (exception &e)
 		{
@@ -666,6 +711,12 @@ namespace TrueCrypt
 		}
 	}
 
+	void MainFrame::OnBenchmarkMenuItemSelected (wxCommandEvent& event)
+	{
+		BenchmarkDialog dialog (this);
+		dialog.ShowModal();
+	}
+
 	void MainFrame::OnClearSlotSelectionMenuItemSelected (wxCommandEvent& event)
 	{
 		Gui->ClearListCtrlSelection (SlotListCtrl);
@@ -965,7 +1016,17 @@ namespace TrueCrypt
 			SelectedItemIndex = event.GetIndex();
 			OnListItemSelectionChanged();
 		}
+
+		if (!ListItemRightClickEventPending)
+		{
+			ListItemRightClickEventPending = true;
+			SlotListCtrl->AddPendingEvent (event);
+			return;
+		}
+
+		ListItemRightClickEventPending = false;
 #endif
+
 		wxMenu popup;
 		if (IsMountedSlotSelected())
 		{
@@ -1000,8 +1061,6 @@ namespace TrueCrypt
 
 			PopupMenu (&popup);
 		}
-
-		event.Skip();
 	}
 
 	void MainFrame::OnListItemSelected (wxListEvent& event)
@@ -1235,6 +1294,21 @@ namespace TrueCrypt
 					Close (true);
 				}
 			}
+
+#if defined(TC_UNIX) && !defined(TC_MACOSX)
+			try
+			{
+				byte buf[128];
+				if (read (ShowRequestFifo, buf, sizeof (buf)) > 0 && Gui->IsInBackgroundMode())
+					Gui->SetBackgroundMode (false);
+			}
+			catch (...)
+			{
+#ifdef DEBUG
+				throw;
+#endif
+			}
+#endif
 		}
 		catch (exception &e)
 		{
