@@ -1,9 +1,9 @@
 /*
- Copyright (c) 2008 TrueCrypt Foundation. All rights reserved.
+ Copyright (c) 2008-2010 TrueCrypt Developers Association. All rights reserved.
 
- Governed by the TrueCrypt License 2.8 the full text of which is contained
- in the file License.txt included in TrueCrypt binary and source code
- distribution packages.
+ Governed by the TrueCrypt License 3.0 the full text of which is contained in
+ the file License.txt included in TrueCrypt binary and source code distribution
+ packages.
 */
 
 #ifndef TC_HEADER_Main_Forms_VolumeSizeWizardPage
@@ -16,12 +16,12 @@ namespace TrueCrypt
 	class VolumeSizeWizardPage : public VolumeSizeWizardPageBase
 	{
 	public:
-		VolumeSizeWizardPage (wxPanel* parent, const VolumePath &volumePath, const wxString &freeSpaceText = wxEmptyString);
+		VolumeSizeWizardPage (wxPanel* parent, const VolumePath &volumePath, uint32 sectorSize, const wxString &freeSpaceText = wxEmptyString);
 
 		uint64 GetVolumeSize () const;
 		bool IsValid ();
 		void SetMaxStaticTextWidth (int width);
-		void SetMaxVolumeSize (uint64 size) { MaxVolumeSize = size; }
+		void SetMaxVolumeSize (uint64 size) { MaxVolumeSize = size; MaxVolumeSizeValid = true; }
 		void SetMinVolumeSize (uint64 size) { MinVolumeSize = size; }
 		void SetPageText (const wxString &text) { InfoStaticText->SetLabel (text); }
 		void SetVolumeSize (uint64 size);
@@ -42,7 +42,9 @@ namespace TrueCrypt
 		void OnVolumeSizeTextChanged (wxCommandEvent& event) { PageUpdatedEvent.Raise(); }
 
 		uint64 MaxVolumeSize;
+		bool MaxVolumeSizeValid;
 		uint64 MinVolumeSize;
+		uint32 SectorSize;
 	};
 }
 
