@@ -1,9 +1,9 @@
 /*
- Copyright (c) 2008 TrueCrypt Foundation. All rights reserved.
+ Copyright (c) 2008-2010 TrueCrypt Developers Association. All rights reserved.
 
- Governed by the TrueCrypt License 2.8 the full text of which is contained
- in the file License.txt included in TrueCrypt binary and source code
- distribution packages.
+ Governed by the TrueCrypt License 3.0 the full text of which is contained in
+ the file License.txt included in TrueCrypt binary and source code distribution
+ packages.
 */
 
 #ifndef TC_HEADER_Main_VolumeHistory
@@ -24,6 +24,7 @@ namespace TrueCrypt
 		static void Clear ();
 		static void ConnectComboBox (wxComboBox *comboBox);
 		static void DisconnectComboBox (wxComboBox *comboBox);
+		static VolumePathList Get () { return VolumePaths; }
 		static void Load ();
 		static void Save ();
 
