@@ -1,11 +1,12 @@
 /*
- Copyright (c) 2008 TrueCrypt Foundation. All rights reserved.
+ Copyright (c) 2008 TrueCrypt Developers Association. All rights reserved.
 
- Governed by the TrueCrypt License 2.8 the full text of which is contained
- in the file License.txt included in TrueCrypt binary and source code
- distribution packages.
+ Governed by the TrueCrypt License 3.0 the full text of which is contained in
+ the file License.txt included in TrueCrypt binary and source code distribution
+ packages.
 */
 
+#include "Common/Tcdefs.h"
 #include "Memory.h"
 #include "Exception.h"
 
@@ -41,7 +42,7 @@ namespace TrueCrypt
 
 	void Memory::Erase (void *memory, size_t size)
 	{
-		Zero (memory, size);
+		burn (memory, size);
 	}
 
 	void Memory::Zero (void *memory, size_t size)
